@@ -86,7 +86,7 @@ class Organization:
                 for link in default_creds_chain:
                     candidate = link['base']+"/"+self.credentials
                     if os.path.exists(candidate):
-                        print("INFO: using default {scope} credentials in {path}".format(
+                        print("INFO: using credentials in {path} (found in {scope}-default directory)".format(
                             scope=link['scope'],
                             path=candidate
                         ))
@@ -174,7 +174,16 @@ class Organization:
             self.organizations_by_label = dict()
             for org in self.get_organizations():
                 self.organizations_by_label[org['label']] = org['id']
-            self.describe = self.get_organization(id=self.organizations_by_label[organization_label])
+            if organization_label in self.organizations_by_label.keys():
+                self.describe = self.get_organization(id=self.organizations_by_label[organization_label])
+            else:
+                raise Exception(
+                    'ERROR: failed to find org label {:s} in the list of orgs {:s}'.format(
+                        organization_label,
+                        str(self.organizations_by_label.keys())
+                    )
+                )
+
         else:
             self.describe = self.get_organization(id=self.caller['organizationId'])
 
